@@ -43,16 +43,14 @@
         <translation type="unfinished">О программе</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="268"/>		
+        <source>About Qt</source>
         <translation type="unfinished">Qt</translation>
     </message>	
     <message>
-        <location filename="settingsdialog.ui" line="88"/>	
         <source>Font</source>
         <translation type="unfinished">Шрифт</translation>
     </message>	
     <message>
-        <location filename="settingsdialog.ui" line="98"/>	
         <source>Default (LCD)</source>
         <translation type="unfinished">Исходный (LCD)</translation>
     </message>	
@@ -61,17 +59,14 @@
         <translation type="unfinished">О программе DigiClock</translation>
     </message>	
     <message>
-        <location filename="settingsdialog.ui" line="118"/>	
         <source>B</source>
         <translation type="unfinished">Ж</translation>
     </message>	
     <message>
-        <location filename="settingsdialog.ui" line="136"/>	
         <source>I</source>
         <translation type="unfinished">К</translation>
     </message>	
     <message>
-        <location filename="settingsdialog.ui" line="155"/>	
         <source>12:48</source>
         <translation type="unfinished"></translation>
     </message>
@@ -107,33 +102,25 @@
         <source>Show City name</source>
         <translation type="unfinished">Название Города</translation>
     </message>
+    <message>
+        <source>Show Date</source>
+        <translation type="unfinished">Дата</translation>
+    </message>
+    <message>
+        <source>full date</source>
+        <translation type="unfinished">полная</translation>
+    </message>	
     <message>
         <source>Open Clock app on Click</source>
         <translation type="unfinished">Открывать часы по клику</translation>
     </message>
-    <message>
-        <source>Enable Autorotation</source>
-        <translation type="unfinished">Разрешить Автоповорот</translation>
-    </message>
-    <message>
-        <source>DigiClock</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Developed with</source>
-        <translation type="unfinished">Написано на</translation>
-    </message>
-    <message>
-        <source>Desktop widget, showing digital time</source>
-        <translation type="unfinished">Виджет, отображающий время в цифровом формате</translation>
-    </message>
-    <message>
-        <source>Send reports to:</source>
-        <translation type="unfinished">Письмо автору:</translation>
-    </message>
     <message>
         <source>Rotation</source>
         <translation type="unfinished">Вращение</translation>
+    </message>	
+    <message>
+        <source>Enable Autorotation</source>
+        <translation type="unfinished">Разрешить Автоповорот</translation>
     </message>
     <message>
         <source>Fixed Corner</source>
@@ -155,5 +142,21 @@
         <source>Bottom Right</source>
         <translation type="unfinished">Нижний Правый</translation>
     </message>	
+    <message>
+        <source>DigiClock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Developed with</source>
+        <translation type="unfinished">Написано на</translation>
+    </message>
+    <message>
+        <source>Desktop widget, showing digital time</source>
+        <translation type="unfinished">Виджет, отображающий время в цифровом формате</translation>
+    </message>
+    <message>
+        <source>Send reports to:</source>
+        <translation type="unfinished">Письмо автору:</translation>
+    </message>	
 </context>
 </TS>
