@@ -8,6 +8,8 @@
 #include <QtDBus/QtDBus>
 #include <mce/mode-names.h>
 #include <mce/dbus-names.h>
+#include <cityinfo.h>
+#include <clockd/libtime.h>
 #endif
 
 #include "digitalclockwdg.h"
@@ -45,6 +47,12 @@ DigitalClockWdg::DigitalClockWdg(QGraphicsScene *scene)
     m_gDate = m_scene->addText("");
     m_gDate->setPos(-size().width(),-size().height());
 
+    //TODO generate empy pixmap
+    QPixmap bgPix = QPixmap(1,1);
+    bgPix.fill(Qt::transparent);
+    mBgImage = m_scene->addPixmap(bgPix);
+    mBgImage->setPos(-size().width(),-size().height());
+
     setViewportUpdateMode(QGraphicsView::BoundingRectViewportUpdate);
     setCacheMode(QGraphicsView::CacheNone);
     setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
@@ -58,7 +66,8 @@ void DigitalClockWdg::setId(QString &aAppletId)
 {
     m_aplletId = aAppletId;
     loadSettings();
-//showSettingsDialog();    //!!
+
+//showSettingsDialog();    //TODO remove in release
 //    initClock();
 }
 
@@ -79,8 +88,10 @@ int DigitalClockWdg::drawCityName()
     m_scene->removeItem(m_gCity);
     m_gLine = m_scene->addLine(0,0,size().width(),0, pen);
     m_gLine->setPos(m_sc_x,y + 4);
+    m_gLine->setZValue(1);
     m_gCity = m_scene->addText(m_cityName,fnt);
     m_gCity->setPos(m_sc_x + (size().width()-m_wCity)/2,m_sc_y);
+    m_gCity->setZValue(1);
     return textSize + 4;
 }
 
@@ -100,9 +111,11 @@ int DigitalClockWdg::drawDate()
     m_scene->removeItem(m_gDate);
     m_gLine2 = m_scene->addLine(0,0,size().width(),0, pen);
     m_gLine2->setPos(m_sc_x,y+2);
+    m_gLine2->setZValue(1);
     m_gDate = m_scene->addText(m_dateString,fnt);
     m_gDate->setPos(m_sc_x + (size().width()-m_wDate)/2,m_sc_y - 4);
     m_gDate->setDefaultTextColor(m_digitColor);
+    m_gDate->setZValue(1);
     return textSize + 4;
 }
 
@@ -166,6 +179,7 @@ void DigitalClockWdg::initClock()
     m_gProxy = m_scene->addWidget(clk1);
 //    m_gProxy->resize(asize);
     m_gProxy->setPos(m_sc_x,m_sc_y);
+    m_gProxy->setZValue(1);
 }
 
 QString DigitalClockWdg::calcDate()
@@ -196,6 +210,15 @@ QTime DigitalClockWdg::calcTime()
     else
     {
         QDateTime dt = QDateTime::currentDateTime();
+        int mint = dt.time().minute();
+        if (mint == 0) // check offset every hour to catch daylight saving change
+        {
+            int secs = dt.time().second();
+            if (secs == 0)
+            {
+                calcOffset();
+            }
+        }
         QDateTime udt = dt.toUTC();
         dt = udt.addSecs(m_tzOffset);
         return dt.time();
@@ -256,7 +279,6 @@ void DigitalClockWdg::loadSettings()
 
     m_showDate =  dclocksettings::getInstance().isShowDateEnabled(m_aplletId);
     m_fullDateFormat = dclocksettings::getInstance().isFullDateFormat(m_aplletId);
-    m_dateSize = dclocksettings::getInstance().getDateSize(m_aplletId);
 
 #else
     m_digitColor = QColor(Qt::blue);
@@ -313,22 +335,32 @@ void DigitalClockWdg::loadSettings()
 
         }
 
-    bool rotatable;
+    //TODO new rotate feature
+    //bool rotatable;
+    int rotatePolicy = 1; // default
 #if  defined(Q_WS_MAEMO_5)
     m_lcd = dclocksettings::getInstance().isLcd(m_aplletId);
     m_font = dclocksettings::getInstance().getFont(m_aplletId);
-    m_tzOffset = dclocksettings::getInstance().getTZoffset(m_aplletId);
-    int aTr = 255 - dclocksettings::getInstance().getTransparency(m_aplletId);
-    rotatable = dclocksettings::getInstance().isRotateEnabled(m_aplletId);
+    //TODO new lines
+    // time zone offset calc
+    mCityIndex = dclocksettings::getInstance().getTZoffset(m_aplletId);
+    if (mCityIndex > -1)
+        calcOffset();
+    else
+        m_tzOffset = -50000;
+
+//    m_tzOffset = dclocksettings::getInstance().getTZoffset(m_aplletId);
+//    rotatable = dclocksettings::getInstance().isRotateEnabled(m_aplletId);
+    rotatePolicy = dclocksettings::getInstance().getRotatePolicy(m_aplletId);
 #else
     m_lcd = false;
     m_font = QFont("Helvetica",30);
-    m_tzOffset = 14400;
-    float aTr = float(50);
-    rotatable = false;
+    m_tzOffset = -50000;
+//    float aTr = float(50);
+//    rotatable = false;
 #endif
 //    m_transparency = aTr/100;
-
+    int aTr = 255 - dclocksettings::getInstance().getTransparency(m_aplletId);
     QPalette qp = palette();
     QColor qc = qp.color(QPalette::Window);
     qc.setAlpha(aTr);
@@ -336,6 +368,7 @@ void DigitalClockWdg::loadSettings()
 
     m_cityName = dclocksettings::getInstance().getTZcity(m_aplletId);
     m_citySize = dclocksettings::getInstance().getCitySize(m_aplletId);
+    m_dateSize = dclocksettings::getInstance().getDateSize(m_aplletId);
 
     m_timer->stop();
     m_timer->start(1000);
@@ -343,8 +376,26 @@ void DigitalClockWdg::loadSettings()
     m_sc_y = -m_size.height()/2;
     m_scene->setSceneRect(m_sc_x, m_sc_y,m_size.width(),m_size.height());
     resize(m_size.width(),m_size.height());
+
+    //TODO add background pic
+    QString bgPicFile = dclocksettings::getInstance().getImageFile(m_aplletId);
+    QPixmap bgPix(bgPicFile);
+    int swd = m_scene->sceneRect().width();
+    int sht = m_scene->sceneRect().height();
+    bgPix = bgPix.scaled(swd,sht,Qt::IgnoreAspectRatio);
+    m_scene->removeItem(mBgImage);
+    mBgImage = m_scene->addPixmap(bgPix);
+    mBgImage->setPos(m_sc_x, m_sc_y);
+    mBgImage->setZValue(0);
+    //TODO maybe here will be opacity
+    mBgImage->setOpacity((qreal)aTr/255);
+
+    qDebug()<< QString("pic is set");
+
     initClock();
-    enableRotationMonitor(rotatable);    // !! to test
+//    enableRotationMonitor(rotatable);
+    m_rotate = false;
+    enableRotationMonitor(rotatePolicy);
 }
 
 void DigitalClockWdg::homeScreenChanged(bool isOnCurrentHomescreen)
@@ -389,27 +440,45 @@ void DigitalClockWdg::showClock()
 #endif
 }
 
-void DigitalClockWdg::enableRotationMonitor(bool aRotatable)
+//void DigitalClockWdg::enableRotationMonitor(bool aRotatable)
+void DigitalClockWdg::enableRotationMonitor(int aRotatePolicy)
 {
 #if  defined(Q_WS_MAEMO_5)
     m_rotate = false;
-    if (aRotatable)
+//    if (aRotatable)
+    //TODO new rotation feature
+    switch (aRotatePolicy)
     {
+    case 0:
         QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
             MCE_REQUEST_IF, MCE_ACCELEROMETER_ENABLE_REQ));
         QDBusConnection::systemBus().connect("", MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
             MCE_DEVICE_ORIENTATION_SIG, this, SLOT(orientationChanged(QString)));
-    }
-    else
-    {
+        qDebug()<< QString("set rotation to 0");
+        break;
+    case 1:
+        QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
+            MCE_REQUEST_IF, MCE_ACCELEROMETER_DISABLE_REQ));
+        QDBusConnection::systemBus().disconnect("", MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
+            MCE_DEVICE_ORIENTATION_SIG, this, SLOT(orientationChanged(QString)));
+//        m_rotate = true;
+        orientationChanged(QLatin1String(""));
+        m_rotate = false;
+        qDebug()<< QString("set rotation to 1");
+        break;
+    case 2:
         QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
             MCE_REQUEST_IF, MCE_ACCELEROMETER_DISABLE_REQ));
         QDBusConnection::systemBus().disconnect("", MCE_SIGNAL_PATH, MCE_SIGNAL_IF,
             MCE_DEVICE_ORIENTATION_SIG, this, SLOT(orientationChanged(QString)));
         m_rotate = false;
+        orientationChanged(QLatin1String(MCE_ORIENTATION_PORTRAIT));
+        qDebug()<< QString("set rotation to 2");
+        break;
     }
 #else
     m_rotate = true;
+    Q_UNUSED(aRotatePolicy);
 #endif
 }
 
@@ -486,3 +555,13 @@ void DigitalClockWdg::orientationChanged(QString aMessage)
     }
 #endif
 }
+
+void DigitalClockWdg::calcOffset()
+{
+#if  defined(Q_WS_MAEMO_5)
+    Cityinfo **cities = cityinfo_get_all();
+    int offset = time_get_utc_offset(cityinfo_get_zone(cities[mCityIndex]));
+    cityinfo_free_all(cities);
+    m_tzOffset = -offset;
+#endif
+}
