@@ -9,10 +9,11 @@ class FontClock : public QWidget
     Q_OBJECT
 public:
 //    explicit FontClock(QColor &aColor, QString &aFormat, QFont &aFont, int aBlink1, int aBlink2, QWidget *parent = 0);
-    explicit FontClock(QColor &aColor, QFont &aFont, QString &aTime, QWidget *parent = 0);
+    explicit FontClock(QColor &aColor, QFont &aFont, QString &aTime, QSize &aSize);
 
 public slots:
     void showTime(QString aTime);
+    void rotate();
 
 private:
 //    void showTime();
@@ -20,6 +21,7 @@ private:
 
 protected:
     void paintEvent(QPaintEvent *event);
+    void resizeEvent (QResizeEvent * event );
 
 private:
     int m_fntSize;
