@@ -4,18 +4,24 @@
 
 //LcdClock::LcdClock(QColor &aColor, QString &aFormat, int aBlink1, int aBlink2, QWidget *parent)
 //    : QLCDNumber(parent),  m_timeFormat(aFormat), m_blink1(aBlink1), m_blink2(aBlink2)
-LcdClock::LcdClock(QColor &aColor, QString &aTime, QWidget *parent)
-    : QLCDNumber(parent)
+LcdClock::LcdClock(QColor &aColor, QString &aTime,  QSize &aSize)
+    : QLCDNumber()
 {
     setSegmentStyle(Filled);
-    QSize aa = parent->size();
-    resize(aa);
+//    QSize aa = aSize;
+    resize(aSize);
+
+//    setWindowOpacity(0.4);
+
     QPalette qp;
     qp.setColor(QPalette::WindowText,aColor );
     qp.setColor(QPalette::Window,Qt::transparent );
+//    qp.setColor(QPalette::Window,Qt::blue );
     setPalette(qp);
+    setSegmentStyle(QLCDNumber::Flat);
     setDigitCount(aTime.length());
-    setAttribute(Qt::WA_TranslucentBackground);
+
+//    setAttribute(Qt::WA_TranslucentBackground);
     setLineWidth(0);
     showTime(aTime);
 }
@@ -36,3 +42,10 @@ void LcdClock::showTime(QString aTime)
     }*/
     display(aTime);
 }
+
+void LcdClock::rotate()
+{
+    int wd = size().width();
+    int hg = size().height();
+    resize(QSize(hg,wd));
+}
