@@ -3,6 +3,7 @@
 #include <QMessageBox>
 #include <QFontDatabase>
 #include <QDateTime>
+#include <QFileDialog>
 //#include <QStateMachine>
 
 #if defined(Q_WS_MAEMO_5)
@@ -14,10 +15,10 @@
 #include "ui_settingsdialog.h"
 #include "dclocksettings.h"
 
-#define STR_VERSION "0.4.4"
+#define STR_VERSION "0.5.0"
 #define STR_CRLF "<br>"
 #define STR_QT_VERSION "<b>Qt 4.6.2</b>"
-#define STR_COPYRIGHT "Copyright (c) 2010 Avis"
+#define STR_COPYRIGHT "Copyright (c) 2010-2011 Avis"
 #define STR_EMAIL "<a href=\"mailto:avis@allnokia.ru\">avis@allnokia.ru</a>"
 #define STR_DONATE "<a href=https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=TBV3R4AU2PVHS>Donate</a>"
 
@@ -31,7 +32,8 @@ SettingsDialog::SettingsDialog(QString &aAppletId, QWidget *parent) :
     ui->chbItalic->setEnabled(false);
     fillTZlist(ui->cbTZ);
 
-    rotateToggle(false);
+//    rotateToggle(false);
+    rotateChanget(1);
     loadSettings();
 }
 
@@ -117,10 +119,14 @@ void SettingsDialog::dumpSettings() const
     int tzIndex = ui->cbTZ->currentIndex();
     int tzOffset = ui->cbTZ->itemData(tzIndex,Qt::UserRole).toInt();
     int defOffest = calcOffset();
+    //TODO new lines
+    int cityIndex = ui->cbTZ->itemData(tzIndex,Qt::UserRole+1).toInt();
     if (tzOffset == defOffest)
-        dclocksettings::getInstance().setTZoffset(m_appletId,-50000);
+//        dclocksettings::getInstance().setTZoffset(m_appletId,-50000);
+        dclocksettings::getInstance().setTZoffset(m_appletId,-1);
     else
-        dclocksettings::getInstance().setTZoffset(m_appletId,tzOffset);
+//        dclocksettings::getInstance().setTZoffset(m_appletId,tzOffset);
+        dclocksettings::getInstance().setTZoffset(m_appletId,cityIndex);
     dclocksettings::getInstance().setTZindex(m_appletId,tzIndex);
     QString tzCity = ui->cbTZ->currentText();
     int strpos1 = tzCity.indexOf(",");
@@ -130,7 +136,9 @@ void SettingsDialog::dumpSettings() const
         tzCity = "unknown";
     dclocksettings::getInstance().setTZcity(m_appletId,tzCity);
     dclocksettings::getInstance().setTransparency(m_appletId,ui->hzSliderTransparency->value());
-    dclocksettings::getInstance().setRotateEnabled(m_appletId,ui->chbRotate->isChecked());
+//    dclocksettings::getInstance().setRotateEnabled(m_appletId,ui->chbRotate->isChecked());
+    //TODO new rotate policy
+    dclocksettings::getInstance().setRotatePolicy(m_appletId,ui->cboxRotate->currentIndex());
     dclocksettings::getInstance().setOpenClockEnabled(m_appletId,ui->chbOpenClock->isChecked());
     dclocksettings::getInstance().setShowCityEnabled(m_appletId,ui->chbShowCity->isChecked());
     dclocksettings::getInstance().setCitySize(m_appletId,ui->spinCitySize->value());
@@ -148,6 +156,9 @@ void SettingsDialog::dumpSettings() const
     dclocksettings::getInstance().setShowDateEnabled(m_appletId,ui->cbShowDate->isChecked());
     dclocksettings::getInstance().setFullDateFormat(m_appletId,ui->cbFullDate->isChecked());
     dclocksettings::getInstance().setDateSize(m_appletId,ui->spinDateSize->value());
+
+    //TODO save image file path
+    dclocksettings::getInstance().setImageFile(m_appletId,mImageFile);
 }
 
 int SettingsDialog::calcOffset() const
@@ -172,7 +183,9 @@ void SettingsDialog::loadSettings()
     ui->spinHeight->setValue(wSize.height());
     ui->chbBlink->setChecked(dclocksettings::getInstance().isBlinking(m_appletId));
     ui->hzSliderTransparency->setValue(dclocksettings::getInstance().getTransparency(m_appletId));
-    ui->chbRotate->setChecked(dclocksettings::getInstance().isRotateEnabled(m_appletId));
+//    ui->chbRotate->setChecked(dclocksettings::getInstance().isRotateEnabled(m_appletId));
+    //TODO new rotate policy
+    ui->cboxRotate->setCurrentIndex(dclocksettings::getInstance().getRotatePolicy(m_appletId));
     ui->chbOpenClock->setChecked(dclocksettings::getInstance().isOpenClockEnabled(m_appletId));
     ui->chbShowCity->setChecked(dclocksettings::getInstance().isShowCityEnabled(m_appletId));
     ui->spinCitySize->setValue(dclocksettings::getInstance().getCitySize(m_appletId));
@@ -181,6 +194,9 @@ void SettingsDialog::loadSettings()
     ui->cbFullDate->setChecked(dclocksettings::getInstance().isFullDateFormat(m_appletId));
     ui->spinDateSize->setValue(dclocksettings::getInstance().getDateSize(m_appletId));
 
+    mImageFile = dclocksettings::getInstance().getImageFile(m_appletId);
+    updateBackImage();
+
     int aCorner = dclocksettings::getInstance().getCornerNumber(m_appletId);
     switch (aCorner)
     {
@@ -198,25 +214,11 @@ void SettingsDialog::loadSettings()
         break;
     }
 
-//    int tzOffset = dclocksettings::getInstance().getTZoffset(m_appletId);
     int tzIndex = dclocksettings::getInstance().getTZindex(m_appletId);
-//    QString tzCity = dclocksettings::getInstance().getTZcity(m_appletId);
     if (tzIndex > -1)
     {
         ui->cbTZ->setCurrentIndex(tzIndex);
     }
-//    if (tzOffset != -50000)
-  //  {
-        // calc current time zone
-/*        QDateTime dt = QDateTime::currentDateTime();
-        QDateTime udt = dt.toUTC();
-        QTime tm = dt.time();
-        QTime utm = udt.time();*/
-//        tzOffset = calcOffset();
-//        m_defTZoffset = tzOffset; // save current TZ offset
-//    }
-//    int i = ui->cbTZ->findData(tzOffset, int(Qt::UserRole));
-//    ui->cbTZ->setCurrentIndex(i);
 
     if (dclocksettings::getInstance().isLcd(m_appletId))
         ui->cbFont->setCurrentIndex(0);
@@ -320,6 +322,8 @@ void SettingsDialog::fillTZlist(QComboBox* &aBox)
         else
             timeoffset = QString("%2, %1, (UTC %3:%4)").arg(name).arg(country).arg(sign+QString::number(-offset/3600)).arg("30");
         aBox->addItem(timeoffset,-offset);
+        //TODO new lines
+        aBox->setItemData(aBox->count()-1,i,Qt::UserRole+1); // city index
         if (zone == defTZ)
             defTZ = timeoffset;
     }
@@ -327,12 +331,16 @@ void SettingsDialog::fillTZlist(QComboBox* &aBox)
     aBox->model()->sort(0);
     int k = aBox->findText(defTZ);
     aBox->setCurrentIndex(k);
+#else
+    Q_UNUSED(aBox);
 #endif
 }
 
-void SettingsDialog::rotateToggle(bool aState)
+//TODO new rotation feature
+void SettingsDialog::rotateChanget(int aIndex)
 {
-    if (aState)
+    if ((aIndex == 0) || (aIndex == 2))
+//    if (aState)
     {
         ui->groupBox->setEnabled(true);
     }
@@ -341,3 +349,22 @@ void SettingsDialog::rotateToggle(bool aState)
         ui->groupBox->setEnabled(false);
     }
 }
+
+//TODO set background picture
+void SettingsDialog::setBack()
+{
+    QString fileName;
+    fileName = QFileDialog::getOpenFileName(this, tr("Open Picture"),
+               QDir::rootPath(), tr("Image Files (*.jpg *.png)"));
+    if (!fileName.isEmpty()) {
+        mImageFile = fileName;
+        updateBackImage();
+    }
+}
+
+void SettingsDialog::updateBackImage()
+{
+    ui->btnSetBack->setIcon(QIcon(mImageFile));
+    //TODO test for best image size
+    ui->btnSetBack->setIconSize(QSize(46,20));
+}
