@@ -26,7 +26,8 @@ public slots:
 private slots:
     void showAbout();
     void showQtAbout();
-    void rotateToggle(bool);
+    void rotateChanget(int aIndex);
+    void setBack();
 
 private:
     void loadSettings();
@@ -34,11 +35,13 @@ private:
 //    void fillCbTZ();
     int calcOffset() const;
     void fillTZlist(QComboBox* &aBox);
+    void updateBackImage();
 
 private:
     QString m_appletId;
     Ui::SettingsDialog *ui;
     QFont m_font;
+    QString mImageFile;
 //    int m_defTZoffset;
 };
 
